Learn R Programming

ggseas (version 0.3.0)

stat_index: Index Stat

Description

Convert a time series from the original scale to an index for ggplot2

Usage

stat_index(mapping = NULL, data = NULL, geom = "line",
  position = "identity", show.legend = NA, inherit.aes = TRUE,
  index.ref = NULL, index.basis = 100, ...)

Arguments

mapping
Set of aesthetic mappings created by aes or aes_. If specified and inherit.aes = TRUE (the default), it is combined with the default mapping at the t
data
The data to be displayed in this layer. There are three options: If NULL, the default, the data is inherited from the plot data as specified in the call to ggplot. A da
geom
The geometric object to use display the data
position
Position adjustment, either as a string, or the result of a call to a position adjustment function.
show.legend
logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes.
inherit.aes
If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g.
index.ref
if not NULL, a vector of integers indicating which elements of the beginning of each series to use as a reference point for converting to an index. If NULL, no conversion takes place and the data are presented on the original scale.
index.basis
if index.ref is not NULL, the basis point for converting to an index, most commonly 100 or 1000. See examples.
...
other arguments for the geom

See Also

Other time.series.stats.for.ggplot2: stat_decomp, stat_rollapplyr, stat_seas, stat_stl

Examples

Run this code
ap_df <- tsdf(AirPassengers)

ggplot(ldeaths_df, aes(x = YearMon, y = deaths, color = sex)) +
   stat_index(index.ref = 1:12, index.basis = 1000) +
   ylab("Deaths index\n(average of first 12 months = 1000")

Run the code above in your browser using DataLab