Learn R Programming

ggseas (version 0.3.0)

stat_seas: X13 seasonal adjustment Stat

Description

Conducts X13-SEATS-ARIMA seasonal adjustment on the fly for ggplot2

Usage

stat_seas(mapping = NULL, data = NULL, geom = "line",
  position = "identity", show.legend = NA, inherit.aes = TRUE, start,
  frequency, x13_params = NULL, index.ref = NULL, index.basis = 100, ...)

Arguments

mapping
Set of aesthetic mappings created by aes or aes_. If specified and inherit.aes = TRUE (the default), it is combined with the default mapping at the t
data
The data to be displayed in this layer. There are three options: If NULL, the default, the data is inherited from the plot data as specified in the call to ggplot. A da
geom
The geometric object to use display the data
position
Position adjustment, either as a string, or the result of a call to a position adjustment function.
show.legend
logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes.
inherit.aes
If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g.
start
The starting point for the time series, in a format suitable for ts()
frequency
The frequency for the time series
x13_params
a list of other parameters for seas
index.ref
if not NULL, a vector of integers indicating which elements of the beginning of each series to use as a reference point for converting to an index. If NULL, no conversion takes place and the data are presented on the original scale.
index.basis
if index.ref is not NULL, the basis point for converting to an index, most commonly 100 or 1000. See examples.
...
other arguments for the geom

See Also

seas Other time.series.stats.for.ggplot2: stat_decomp, stat_index, stat_rollapplyr, stat_stl

Examples

Run this code
ap_df <- tsdf(AirPassengers)

# SEATS with defaults:
ggplot(ap_df, aes(x = x, y = y)) +
   stat_seas(start = c(1949, 1), frequency = 12)
   
# X11 with no outlier treatment:
ggplot(ap_df, aes(x = x, y = y)) +
  stat_seas(start = c(1949, 1), frequency = 12, x13_params = list(x11 = "", outlier = NULL))

# Multiple time series example:    
ggplot(ldeaths_df, aes(x = YearMon, y = deaths, colour = sex)) +
  geom_point() +
  facet_wrap(~sex) +
  stat_seas(start = c(1974, 1), frequency = 12) +
  ggtitle("Seasonally adjusted lung deaths")
  
# example use of index:  
ggplot(ap_df, aes(x = x, y = y)) +
  stat_seas(start = c(1949, 1), frequency = 12, x13_params = list(x11 = "", outlier = NULL),
  index.ref = 1, index.basis = 1000) +
  labs(y = "Seasonally adjusted index\n(first observation = 1000)")

Run the code above in your browser using DataLab