Learn R Programming

ggseas (version 0.2.0)

stat_seas: X13 seasonal adjustment Stat

Description

Conducts X13-SEATS-ARIMA seasonal adjustment on the fly for ggplot2

Usage

stat_seas(mapping = NULL, data = NULL, geom = "line",
  position = "identity", show.legend = NA, inherit.aes = TRUE, start,
  frequency, x13_params = NULL, ...)

Arguments

mapping
The aesthetic mapping, usually constructed with aes or aes_string. Only needs to be set at the layer level if you are overriding the plot defaults.
data
A layer specific dataset - only needed if you want to override the plot defaults.
geom
The geometric object to use display the data
position
The position adjustment to use for overlapping points on this layer
show.legend
logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes.
inherit.aes
If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g.
start
The starting point for the time series, in a format suitable for ts()
frequency
The frequency for the time series
x13_params
a list of other parameters for seas
...
other arguments for the geom

See Also

seas Other time.series.stats.for.ggplot2: stat_decomp, stat_stl

Examples

Run this code
ap_df <- tsdf(AirPassengers)

# SEATS with defaults
ggplot(ap_df, aes(x = x, y = y)) +
   stat_seas(start = c(1949, 1), frequency = 12)
   
# X11 with no outlier treatment
ggplot(ap_df, aes(x = x, y = y)) +
  stat_seas(start = c(1949, 1), frequency = 12, x13_params = list(x11 = "", outlier = NULL))
   
ggplot(ldeaths_df, aes(x = YearMon, y = deaths, colour = sex)) +
  geom_point() +
  facet_wrap(~sex) +
  stat_seas(start = c(1974, 1), frequency = 12) +
  ggtitle("Seasonally adjusted lung deaths")

Run the code above in your browser using DataLab